==> jc-1.4.0.tar.gz: javax/swing/event/InternalFrameEvent.h <==
// public class javax.swing.event.InternalFrameEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 57156e54edd65c61 javax_swing_event_InternalFrameEvent

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_javax_swing_event_InternalFrameEvent_H_
#define _JC_javax_swing_event_InternalFrameEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JInternalFrame$object;

// Typedefs
typedef struct _jc_javax_swing_event_InternalFrameEvent$sub_refs	_jc_javax_swing_event_InternalFrameEvent$sub_refs;
typedef struct _jc_javax_swing_event_InternalFrameEvent$sub_nonrefs	_jc_javax_swing_event_InternalFrameEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_InternalFrameEvent$refs	_jc_javax_swing_event_InternalFrameEvent$refs;
typedef struct _jc_javax_swing_event_InternalFrameEvent$nonrefs	_jc_javax_swing_event_InternalFrameEvent$nonrefs;
typedef struct _jc_javax_swing_event_InternalFrameEvent$object	_jc_javax_swing_event_InternalFrameEvent$object;

typedef struct _jc_javax_swing_event_InternalFrameEvent$fields_struct	_jc_javax_swing_event_InternalFrameEvent$fields_struct;
typedef const struct _jc_javax_swing_event_InternalFrameEvent$vmethods	_jc_javax_swing_event_InternalFrameEvent$vmethods;
typedef const struct _jc_javax_swing_event_InternalFrameEvent$vtable	_jc_javax_swing_event_InternalFrameEvent$vtable;
typedef const struct _jc_javax_swing_event_InternalFrameEvent$vtype	_jc_javax_swing_event_InternalFrameEvent$vtype;

// Class fields structure
struct _jc_javax_swing_event_InternalFrameEvent$fields_struct {
	jlong	serialVersionUID;
	jint	INTERNAL__5fFRAME__5fACTIVATED;
	jint	INTERNAL__5fFRAME__5fCLOSED;
	jint	INTERNAL__5fFRAME__5fCLOSING;
	jint	INTERNAL__5fFRAME__5fDEACTIVATED;
	jint	INTERNAL__5fFRAME__5fDEICONIFIED;
	jint	INTERNAL__5fFRAME__5fFIRST;
	jint	INTERNAL__5fFRAME__5fICONIFIED;
	jint	INTERNAL__5fFRAME__5fLAST;
	jint	INTERNAL__5fFRAME__5fOPENED;
};
extern _jc_javax_swing_event_InternalFrameEvent$fields_struct _jc_javax_swing_event_InternalFrameEvent$class_fields;

// Constructors
extern void _jc_javax_swing_event_InternalFrameEvent$method$_init$493ec7af7e51cbe3(_jc_env *, struct _jc_javax_swing_event_InternalFrameEvent$object *, struct _jc_javax_swing_JInternalFrame$object *, jint);

// Virtual methods
extern struct _jc_javax_swing_JInternalFrame$object *_jc_javax_swing_event_InternalFrameEvent$method$getInternalFrame$41cafd82a495e64a(_jc_env *, struct _jc_javax_swing_event_InternalFrameEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_InternalFrameEvent$method_info$getInternalFrame$41cafd82a495e64a;

// Virtual methods structure
struct _jc_javax_swing_event_InternalFrameEvent$vmethods {
	struct _jc_javax_swing_JInternalFrame$object	*(*getInternalFrame$41cafd82a495e64a)(_jc_env *, struct _jc_javax_swing_event_InternalFrameEvent$object *);
};

// Vtable
struct _jc_javax_swing_event_InternalFrameEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_javax_swing_event_InternalFrameEvent$vmethods	javax_swing_event_InternalFrameEvent;
};

// Vtype
struct _jc_javax_swing_event_InternalFrameEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_InternalFrameEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_InternalFrameEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_InternalFrameEvent$refs {
    _jc_javax_swing_event_InternalFrameEvent$sub_refs	javax_swing_event_InternalFrameEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_InternalFrameEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_InternalFrameEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_javax_swing_event_InternalFrameEvent$sub_nonrefs	javax_swing_event_InternalFrameEvent;
};

// Object instance structure
struct _jc_javax_swing_event_InternalFrameEvent$object {
	_jc_javax_swing_event_InternalFrameEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_InternalFrameEvent$vtype	*vtype;
	_jc_javax_swing_event_InternalFrameEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_InternalFrameEvent$vtype _jc_javax_swing_event_InternalFrameEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_InternalFrameEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_InternalFrameEvent$class_object;

#endif	/* _JC_javax_swing_event_InternalFrameEvent_H_ */

==> jc-1.4.5.tar.gz: javax/swing/event/InternalFrameEvent.h <==
// public class javax.swing.event.InternalFrameEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 57156e54edd65c61 javax_swing_event_InternalFrameEvent

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_javax_swing_event_InternalFrameEvent_H_
#define _JC_javax_swing_event_InternalFrameEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JInternalFrame$object;

// Typedefs
typedef struct _jc_javax_swing_event_InternalFrameEvent$sub_refs	_jc_javax_swing_event_InternalFrameEvent$sub_refs;
typedef struct _jc_javax_swing_event_InternalFrameEvent$sub_nonrefs	_jc_javax_swing_event_InternalFrameEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_InternalFrameEvent$refs	_jc_javax_swing_event_InternalFrameEvent$refs;
typedef struct _jc_javax_swing_event_InternalFrameEvent$nonrefs	_jc_javax_swing_event_InternalFrameEvent$nonrefs;
typedef struct _jc_javax_swing_event_InternalFrameEvent$object	_jc_javax_swing_event_InternalFrameEvent$object;

typedef struct _jc_javax_swing_event_InternalFrameEvent$fields_struct	_jc_javax_swing_event_InternalFrameEvent$fields_struct;
typedef const struct _jc_javax_swing_event_InternalFrameEvent$vmethods	_jc_javax_swing_event_InternalFrameEvent$vmethods;
typedef const struct _jc_javax_swing_event_InternalFrameEvent$vtable	_jc_javax_swing_event_InternalFrameEvent$vtable;
typedef const struct _jc_javax_swing_event_InternalFrameEvent$vtype	_jc_javax_swing_event_InternalFrameEvent$vtype;

// Class fields structure
struct _jc_javax_swing_event_InternalFrameEvent$fields_struct {
	jlong	serialVersionUID;
	jint	INTERNAL__5fFRAME__5fACTIVATED;
	jint	INTERNAL__5fFRAME__5fCLOSED;
	jint	INTERNAL__5fFRAME__5fCLOSING;
	jint	INTERNAL__5fFRAME__5fDEACTIVATED;
	jint	INTERNAL__5fFRAME__5fDEICONIFIED;
	jint	INTERNAL__5fFRAME__5fFIRST;
	jint	INTERNAL__5fFRAME__5fICONIFIED;
	jint	INTERNAL__5fFRAME__5fLAST;
	jint	INTERNAL__5fFRAME__5fOPENED;
};
extern _jc_javax_swing_event_InternalFrameEvent$fields_struct _jc_javax_swing_event_InternalFrameEvent$class_fields;

// Constructors
extern void _jc_javax_swing_event_InternalFrameEvent$method$_init$493ec7af7e51cbe3(_jc_env *, struct _jc_javax_swing_event_InternalFrameEvent$object *, struct _jc_javax_swing_JInternalFrame$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_JInternalFrame$object *_jc_javax_swing_event_InternalFrameEvent$method$getInternalFrame$41cafd82a495e64a(_jc_env *, struct _jc_javax_swing_event_InternalFrameEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_InternalFrameEvent$method_info$getInternalFrame$41cafd82a495e64a;

// Virtual methods structure
struct _jc_javax_swing_event_InternalFrameEvent$vmethods {
	struct _jc_javax_swing_JInternalFrame$object	*(*getInternalFrame$41cafd82a495e64a)(_jc_env *, struct _jc_javax_swing_event_InternalFrameEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_event_InternalFrameEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_javax_swing_event_InternalFrameEvent$vmethods	javax_swing_event_InternalFrameEvent;
};

// Vtype
struct _jc_javax_swing_event_InternalFrameEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_InternalFrameEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_InternalFrameEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_InternalFrameEvent$refs {
    _jc_javax_swing_event_InternalFrameEvent$sub_refs	javax_swing_event_InternalFrameEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_InternalFrameEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_InternalFrameEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_javax_swing_event_InternalFrameEvent$sub_nonrefs	javax_swing_event_InternalFrameEvent;
};

// Object instance structure
struct _jc_javax_swing_event_InternalFrameEvent$object {
	_jc_javax_swing_event_InternalFrameEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_InternalFrameEvent$vtype	*vtype;
	_jc_javax_swing_event_InternalFrameEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_InternalFrameEvent$vtype _jc_javax_swing_event_InternalFrameEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_InternalFrameEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_InternalFrameEvent$class_object;

#endif	/* _JC_javax_swing_event_InternalFrameEvent_H_ */
